(function($){

	var reginald = {
		init: function(){
			this.cacheDom();
			this.bindEvents();
			this.render();
		},

		cacheDom: function(){
			this.$window = $(window);
			this.$document = $(document);
			this.$htmlAndBody = this.$document.find('html, body');
			this.$html = this.$document.find('html');
			this.$scrollToTop = this.$document.find('#scroll-to-top');
			this.$logo = this.$document.find('.custom-logo');
			this.$siteHeader = this.$document.find('#site-header');
			this.$menuHeaderToggle = this.$document.find('#menu-toggle');
			this.$menuHeaderContainer = this.$document.find('#header-menu-container');
			this.$archiveTitle = this.$document.find('.archive .content-title');
			this.$videoPosts = this.$document.find('.single-format-video .post');
			this.$videoEmbeds = this.$videoPosts.find('iframe, video, embed, object, .video-player, .videopress-placeholder');
		},

		bindEvents: function(){
			this.$window.resize( this.resizeHandler.bind(this) );
			this.$scrollToTop.on( 'click', this.scrollToTop.bind(this) );
			this.$menuHeaderToggle.on( 'click', this.toggleMenu.bind(this) );
			this.$document.on( 'scroll', this.scrollHandler.bind(this) );
		},

		render: function(){
			// Javascript detection
			this.$html.removeClass('no-js').addClass('js');

			// Remove prefix from archive titles
			if( this.$archiveTitle.length ){
				var archiveTitle = this.$archiveTitle.html().split(': ');

				if( archiveTitle.length > 1 ){
					archiveTitle.shift();
					this.$archiveTitle.html( archiveTitle.join(': ') );
				}
			}

			if( this.$logo.length && this.$logo.width() >= 350 ) this.$siteHeader.addClass('wide-logo');

			this.fullWidthVideoEmbeds();
		},

		toggleMenu: function(){
			this.$menuHeaderContainer.toggle()
		},

		scrollToTop: function(){
			this.$htmlAndBody.animate({scrollTop:0}, 'slow');
			return false;
		},

		resizeHandler: function(){
			this.fullWidthVideoEmbeds();
		},

		fullWidthVideoEmbeds: function(){
			if( this.$videoEmbeds.length ){
				for( var x=0; x<this.$videoEmbeds.length; x++){
					var $video = $( this.$videoEmbeds[x] );

					$video.width('100%');
					$video.height( ($video.width()/16) * 9 );
				}
			}
		},

		scrollHandler: function(){
			this.$document.scrollTop() ? this.$scrollToTop.show(500) : this.$scrollToTop.hide(500) ;
		}
	}

	$(document).ready( reginald.init.bind(reginald) );

})(jQuery);
